# lomi-sdk
Payment processing API for francophone West African businesses.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1.0
- Package version: 1.0.0
- Generator version: 7.17.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://lomi.africa](https://lomi.africa)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import lomi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import lomi
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import lomi
from lomi.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.lomi.africa/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = lomi.Configuration(
    host = "https://api.lomi.africa/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with lomi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = lomi.BeneficiaryPayoutsApi(api_client)
    beneficiary_payouts_create = {"name":"Sample beneficiary_payout","description":"Example beneficiary_payout object"} # BeneficiaryPayoutsCreate | 

    try:
        # Create beneficiary payout
        api_response = api_instance.create_beneficiary_payout(beneficiary_payouts_create)
        print("The response of BeneficiaryPayoutsApi->create_beneficiary_payout:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BeneficiaryPayoutsApi->create_beneficiary_payout: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.lomi.africa/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BeneficiaryPayoutsApi* | [**create_beneficiary_payout**](docs/BeneficiaryPayoutsApi.md#create_beneficiary_payout) | **POST** /beneficiary_payouts | Create beneficiary payout
*BeneficiaryPayoutsApi* | [**list_beneficiary_payouts**](docs/BeneficiaryPayoutsApi.md#list_beneficiary_payouts) | **GET** /beneficiary_payouts | List beneficiary payouts
*BeneficiaryPayoutsApi* | [**retrieve_beneficiary_payout**](docs/BeneficiaryPayoutsApi.md#retrieve_beneficiary_payout) | **GET** /beneficiary_payouts/{payout_id} | Retrieve beneficiary payout
*CheckoutSessionsApi* | [**create_checkout_session**](docs/CheckoutSessionsApi.md#create_checkout_session) | **POST** /checkout_sessions | Create checkout session
*CheckoutSessionsApi* | [**delete_checkout_session**](docs/CheckoutSessionsApi.md#delete_checkout_session) | **DELETE** /checkout_sessions/{session_id} | Delete checkout session
*CheckoutSessionsApi* | [**list_checkout_sessions**](docs/CheckoutSessionsApi.md#list_checkout_sessions) | **GET** /checkout_sessions | List checkout sessions
*CheckoutSessionsApi* | [**retrieve_checkout_session**](docs/CheckoutSessionsApi.md#retrieve_checkout_session) | **GET** /checkout_sessions/{session_id} | Retrieve checkout session
*CheckoutSessionsApi* | [**update_checkout_session**](docs/CheckoutSessionsApi.md#update_checkout_session) | **PATCH** /checkout_sessions/{session_id} | Update checkout session
*CustomerInvoicesApi* | [**list_customer_invoices**](docs/CustomerInvoicesApi.md#list_customer_invoices) | **GET** /customer_invoices | List customer invoices
*CustomerInvoicesApi* | [**retrieve_customer_invoice**](docs/CustomerInvoicesApi.md#retrieve_customer_invoice) | **GET** /customer_invoices/{invoice_id} | Retrieve customer invoice
*CustomersApi* | [**create_customer**](docs/CustomersApi.md#create_customer) | **POST** /customers | Create customer
*CustomersApi* | [**delete_customer**](docs/CustomersApi.md#delete_customer) | **DELETE** /customers/{customer_id} | Delete customer
*CustomersApi* | [**list_customers**](docs/CustomersApi.md#list_customers) | **GET** /customers | List customers
*CustomersApi* | [**retrieve_customer**](docs/CustomersApi.md#retrieve_customer) | **GET** /customers/{customer_id} | Retrieve customer
*CustomersApi* | [**update_customer**](docs/CustomersApi.md#update_customer) | **PATCH** /customers/{customer_id} | Update customer
*DiscountCouponsApi* | [**create_discount_coupon**](docs/DiscountCouponsApi.md#create_discount_coupon) | **POST** /discount_coupons | Create discount coupon
*DiscountCouponsApi* | [**delete_discount_coupon**](docs/DiscountCouponsApi.md#delete_discount_coupon) | **DELETE** /discount_coupons/{coupon_id} | Delete discount coupon
*DiscountCouponsApi* | [**list_discount_coupons**](docs/DiscountCouponsApi.md#list_discount_coupons) | **GET** /discount_coupons | List discount coupons
*DiscountCouponsApi* | [**retrieve_discount_coupon**](docs/DiscountCouponsApi.md#retrieve_discount_coupon) | **GET** /discount_coupons/{coupon_id} | Retrieve discount coupon
*DiscountCouponsApi* | [**update_discount_coupon**](docs/DiscountCouponsApi.md#update_discount_coupon) | **PATCH** /discount_coupons/{coupon_id} | Update discount coupon
*EventsApi* | [**list_events**](docs/EventsApi.md#list_events) | **GET** /events | List events
*EventsApi* | [**retrieve_event**](docs/EventsApi.md#retrieve_event) | **GET** /events/{event_id} | Retrieve event
*InstallmentPaymentsApi* | [**list_installment_payments**](docs/InstallmentPaymentsApi.md#list_installment_payments) | **GET** /installment_payments | List installment payments
*InstallmentPaymentsApi* | [**retrieve_installment_payment**](docs/InstallmentPaymentsApi.md#retrieve_installment_payment) | **GET** /installment_payments/{payment_id} | Retrieve installment payment
*MeterBalancesApi* | [**list_meter_balances**](docs/MeterBalancesApi.md#list_meter_balances) | **GET** /meter_balances | List meter balances
*MeterBalancesApi* | [**retrieve_meter_balance**](docs/MeterBalancesApi.md#retrieve_meter_balance) | **GET** /meter_balances/{balance_id} | Retrieve meter balance
*MetersApi* | [**create_meter**](docs/MetersApi.md#create_meter) | **POST** /meters | Create meter
*MetersApi* | [**delete_meter**](docs/MetersApi.md#delete_meter) | **DELETE** /meters/{meter_id} | Delete meter
*MetersApi* | [**list_meters**](docs/MetersApi.md#list_meters) | **GET** /meters | List meters
*MetersApi* | [**retrieve_meter**](docs/MetersApi.md#retrieve_meter) | **GET** /meters/{meter_id} | Retrieve meter
*MetersApi* | [**update_meter**](docs/MetersApi.md#update_meter) | **PATCH** /meters/{meter_id} | Update meter
*PaymentLinksApi* | [**create_payment_link**](docs/PaymentLinksApi.md#create_payment_link) | **POST** /payment_links | Create payment link
*PaymentLinksApi* | [**delete_payment_link**](docs/PaymentLinksApi.md#delete_payment_link) | **DELETE** /payment_links/{link_id} | Delete payment link
*PaymentLinksApi* | [**list_payment_links**](docs/PaymentLinksApi.md#list_payment_links) | **GET** /payment_links | List payment links
*PaymentLinksApi* | [**retrieve_payment_link**](docs/PaymentLinksApi.md#retrieve_payment_link) | **GET** /payment_links/{link_id} | Retrieve payment link
*PaymentLinksApi* | [**update_payment_link**](docs/PaymentLinksApi.md#update_payment_link) | **PATCH** /payment_links/{link_id} | Update payment link
*PaymentRequestsApi* | [**create_payment_request**](docs/PaymentRequestsApi.md#create_payment_request) | **POST** /payment_requests | Create payment request
*PaymentRequestsApi* | [**delete_payment_request**](docs/PaymentRequestsApi.md#delete_payment_request) | **DELETE** /payment_requests/{request_id} | Delete payment request
*PaymentRequestsApi* | [**list_payment_requests**](docs/PaymentRequestsApi.md#list_payment_requests) | **GET** /payment_requests | List payment requests
*PaymentRequestsApi* | [**retrieve_payment_request**](docs/PaymentRequestsApi.md#retrieve_payment_request) | **GET** /payment_requests/{request_id} | Retrieve payment request
*PaymentRequestsApi* | [**update_payment_request**](docs/PaymentRequestsApi.md#update_payment_request) | **PATCH** /payment_requests/{request_id} | Update payment request
*PayoutMethodsApi* | [**list_payout_methods**](docs/PayoutMethodsApi.md#list_payout_methods) | **GET** /payout_methods | List payout methods
*PayoutMethodsApi* | [**retrieve_payout_method**](docs/PayoutMethodsApi.md#retrieve_payout_method) | **GET** /payout_methods/{payout_method_id} | Retrieve payout method
*PayoutsApi* | [**create_payout**](docs/PayoutsApi.md#create_payout) | **POST** /payouts | Create payout
*PayoutsApi* | [**delete_payout**](docs/PayoutsApi.md#delete_payout) | **DELETE** /payouts/{payout_id} | Delete payout
*PayoutsApi* | [**list_payouts**](docs/PayoutsApi.md#list_payouts) | **GET** /payouts | List payouts
*PayoutsApi* | [**retrieve_payout**](docs/PayoutsApi.md#retrieve_payout) | **GET** /payouts/{payout_id} | Retrieve payout
*PayoutsApi* | [**update_payout**](docs/PayoutsApi.md#update_payout) | **PATCH** /payouts/{payout_id} | Update payout
*PricesApi* | [**create_price**](docs/PricesApi.md#create_price) | **POST** /prices | Create price
*PricesApi* | [**delete_price**](docs/PricesApi.md#delete_price) | **DELETE** /prices/{price_id} | Delete price
*PricesApi* | [**list_prices**](docs/PricesApi.md#list_prices) | **GET** /prices | List prices
*PricesApi* | [**retrieve_price**](docs/PricesApi.md#retrieve_price) | **GET** /prices/{price_id} | Retrieve price
*PricesApi* | [**update_price**](docs/PricesApi.md#update_price) | **PATCH** /prices/{price_id} | Update price
*ProductsApi* | [**create_product**](docs/ProductsApi.md#create_product) | **POST** /products | Create product
*ProductsApi* | [**delete_product**](docs/ProductsApi.md#delete_product) | **DELETE** /products/{product_id} | Delete product
*ProductsApi* | [**list_products**](docs/ProductsApi.md#list_products) | **GET** /products | List products
*ProductsApi* | [**retrieve_product**](docs/ProductsApi.md#retrieve_product) | **GET** /products/{product_id} | Retrieve product
*ProductsApi* | [**update_product**](docs/ProductsApi.md#update_product) | **PATCH** /products/{product_id} | Update product
*RefundsApi* | [**create_refund**](docs/RefundsApi.md#create_refund) | **POST** /refunds | Create refund
*RefundsApi* | [**delete_refund**](docs/RefundsApi.md#delete_refund) | **DELETE** /refunds/{refund_id} | Delete refund
*RefundsApi* | [**list_refunds**](docs/RefundsApi.md#list_refunds) | **GET** /refunds | List refunds
*RefundsApi* | [**retrieve_refund**](docs/RefundsApi.md#retrieve_refund) | **GET** /refunds/{refund_id} | Retrieve refund
*RefundsApi* | [**update_refund**](docs/RefundsApi.md#update_refund) | **PATCH** /refunds/{refund_id} | Update refund
*SPIAccountAliasesApi* | [**list_spi_account_aliases**](docs/SPIAccountAliasesApi.md#list_spi_account_aliases) | **GET** /spi_account_aliases | List spi account aliases
*SPIAccountAliasesApi* | [**retrieve_spi_account_aliase**](docs/SPIAccountAliasesApi.md#retrieve_spi_account_aliase) | **GET** /spi_account_aliases/{alias_id} | Retrieve spi account aliase
*SPIQRCodesApi* | [**create_spi_qr_code**](docs/SPIQRCodesApi.md#create_spi_qr_code) | **POST** /spi_qr_codes | Create spi qr code
*SPIQRCodesApi* | [**delete_spi_qr_code**](docs/SPIQRCodesApi.md#delete_spi_qr_code) | **DELETE** /spi_qr_codes/{qr_code_id} | Delete spi qr code
*SPIQRCodesApi* | [**list_spi_qr_codes**](docs/SPIQRCodesApi.md#list_spi_qr_codes) | **GET** /spi_qr_codes | List spi qr codes
*SPIQRCodesApi* | [**retrieve_spi_qr_code**](docs/SPIQRCodesApi.md#retrieve_spi_qr_code) | **GET** /spi_qr_codes/{qr_code_id} | Retrieve spi qr code
*SPIQRCodesApi* | [**update_spi_qr_code**](docs/SPIQRCodesApi.md#update_spi_qr_code) | **PATCH** /spi_qr_codes/{qr_code_id} | Update spi qr code
*SubscriptionsApi* | [**create_subscription**](docs/SubscriptionsApi.md#create_subscription) | **POST** /subscriptions | Create subscription
*SubscriptionsApi* | [**delete_subscription**](docs/SubscriptionsApi.md#delete_subscription) | **DELETE** /subscriptions/{subscription_id} | Delete subscription
*SubscriptionsApi* | [**list_subscriptions**](docs/SubscriptionsApi.md#list_subscriptions) | **GET** /subscriptions | List subscriptions
*SubscriptionsApi* | [**retrieve_subscription**](docs/SubscriptionsApi.md#retrieve_subscription) | **GET** /subscriptions/{subscription_id} | Retrieve subscription
*SubscriptionsApi* | [**update_subscription**](docs/SubscriptionsApi.md#update_subscription) | **PATCH** /subscriptions/{subscription_id} | Update subscription
*TransactionsApi* | [**list_transactions**](docs/TransactionsApi.md#list_transactions) | **GET** /transactions | List transactions
*TransactionsApi* | [**retrieve_transaction**](docs/TransactionsApi.md#retrieve_transaction) | **GET** /transactions/{transaction_id} | Retrieve transaction
*WebhookDeliveryLogsApi* | [**list_webhook_delivery_logs**](docs/WebhookDeliveryLogsApi.md#list_webhook_delivery_logs) | **GET** /webhook_delivery_logs | List webhook delivery logs
*WebhookDeliveryLogsApi* | [**retrieve_webhook_delivery_log**](docs/WebhookDeliveryLogsApi.md#retrieve_webhook_delivery_log) | **GET** /webhook_delivery_logs/{log_id} | Retrieve webhook delivery log
*WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /webhooks | Create webhook
*WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /webhooks/{webhook_id} | Delete webhook
*WebhooksApi* | [**list_webhooks**](docs/WebhooksApi.md#list_webhooks) | **GET** /webhooks | List webhooks
*WebhooksApi* | [**retrieve_webhook**](docs/WebhooksApi.md#retrieve_webhook) | **GET** /webhooks/{webhook_id} | Retrieve webhook
*WebhooksApi* | [**update_webhook**](docs/WebhooksApi.md#update_webhook) | **PATCH** /webhooks/{webhook_id} | Update webhook


## Documentation For Models

 - [BeneficiaryPayouts](docs/BeneficiaryPayouts.md)
 - [BeneficiaryPayoutsCreate](docs/BeneficiaryPayoutsCreate.md)
 - [BeneficiaryPayoutsUpdate](docs/BeneficiaryPayoutsUpdate.md)
 - [BnplStatus](docs/BnplStatus.md)
 - [CheckoutSessionStatus](docs/CheckoutSessionStatus.md)
 - [CheckoutSessions](docs/CheckoutSessions.md)
 - [CheckoutSessionsCreate](docs/CheckoutSessionsCreate.md)
 - [CheckoutSessionsUpdate](docs/CheckoutSessionsUpdate.md)
 - [CurrencyCode](docs/CurrencyCode.md)
 - [CustomerInvoices](docs/CustomerInvoices.md)
 - [CustomerInvoicesCreate](docs/CustomerInvoicesCreate.md)
 - [CustomerInvoicesUpdate](docs/CustomerInvoicesUpdate.md)
 - [Customers](docs/Customers.md)
 - [CustomersCreate](docs/CustomersCreate.md)
 - [CustomersUpdate](docs/CustomersUpdate.md)
 - [DiscountCoupons](docs/DiscountCoupons.md)
 - [DiscountCouponsCreate](docs/DiscountCouponsCreate.md)
 - [DiscountCouponsUpdate](docs/DiscountCouponsUpdate.md)
 - [Error](docs/Error.md)
 - [ErrorError](docs/ErrorError.md)
 - [Events](docs/Events.md)
 - [EventsCreate](docs/EventsCreate.md)
 - [EventsUpdate](docs/EventsUpdate.md)
 - [Frequency](docs/Frequency.md)
 - [InstallmentPayments](docs/InstallmentPayments.md)
 - [InstallmentPaymentsCreate](docs/InstallmentPaymentsCreate.md)
 - [InstallmentPaymentsUpdate](docs/InstallmentPaymentsUpdate.md)
 - [InvoiceStatus](docs/InvoiceStatus.md)
 - [ListBeneficiaryPayouts200Response](docs/ListBeneficiaryPayouts200Response.md)
 - [ListCheckoutSessions200Response](docs/ListCheckoutSessions200Response.md)
 - [ListCustomerInvoices200Response](docs/ListCustomerInvoices200Response.md)
 - [ListCustomers200Response](docs/ListCustomers200Response.md)
 - [ListCustomers200ResponsePagination](docs/ListCustomers200ResponsePagination.md)
 - [ListDiscountCoupons200Response](docs/ListDiscountCoupons200Response.md)
 - [ListEvents200Response](docs/ListEvents200Response.md)
 - [ListInstallmentPayments200Response](docs/ListInstallmentPayments200Response.md)
 - [ListMeterBalances200Response](docs/ListMeterBalances200Response.md)
 - [ListMeters200Response](docs/ListMeters200Response.md)
 - [ListPaymentLinks200Response](docs/ListPaymentLinks200Response.md)
 - [ListPaymentRequests200Response](docs/ListPaymentRequests200Response.md)
 - [ListPayoutMethods200Response](docs/ListPayoutMethods200Response.md)
 - [ListPayouts200Response](docs/ListPayouts200Response.md)
 - [ListPrices200Response](docs/ListPrices200Response.md)
 - [ListProducts200Response](docs/ListProducts200Response.md)
 - [ListRefunds200Response](docs/ListRefunds200Response.md)
 - [ListSpiAccountAliases200Response](docs/ListSpiAccountAliases200Response.md)
 - [ListSpiQrCodes200Response](docs/ListSpiQrCodes200Response.md)
 - [ListSubscriptions200Response](docs/ListSubscriptions200Response.md)
 - [ListTransactions200Response](docs/ListTransactions200Response.md)
 - [ListWebhookDeliveryLogs200Response](docs/ListWebhookDeliveryLogs200Response.md)
 - [ListWebhooks200Response](docs/ListWebhooks200Response.md)
 - [MeterBalances](docs/MeterBalances.md)
 - [MeterBalancesCreate](docs/MeterBalancesCreate.md)
 - [MeterBalancesUpdate](docs/MeterBalancesUpdate.md)
 - [Meters](docs/Meters.md)
 - [MetersCreate](docs/MetersCreate.md)
 - [MetersUpdate](docs/MetersUpdate.md)
 - [PaymentLinks](docs/PaymentLinks.md)
 - [PaymentLinksCreate](docs/PaymentLinksCreate.md)
 - [PaymentLinksUpdate](docs/PaymentLinksUpdate.md)
 - [PaymentMethodCode](docs/PaymentMethodCode.md)
 - [PaymentRequests](docs/PaymentRequests.md)
 - [PaymentRequestsCreate](docs/PaymentRequestsCreate.md)
 - [PaymentRequestsUpdate](docs/PaymentRequestsUpdate.md)
 - [PayoutMethods](docs/PayoutMethods.md)
 - [PayoutMethodsCreate](docs/PayoutMethodsCreate.md)
 - [PayoutMethodsUpdate](docs/PayoutMethodsUpdate.md)
 - [PayoutStatus](docs/PayoutStatus.md)
 - [Payouts](docs/Payouts.md)
 - [PayoutsCreate](docs/PayoutsCreate.md)
 - [PayoutsUpdate](docs/PayoutsUpdate.md)
 - [Prices](docs/Prices.md)
 - [PricesCreate](docs/PricesCreate.md)
 - [PricesUpdate](docs/PricesUpdate.md)
 - [PricingModelEnum](docs/PricingModelEnum.md)
 - [ProductTypeEnum](docs/ProductTypeEnum.md)
 - [Products](docs/Products.md)
 - [ProductsCreate](docs/ProductsCreate.md)
 - [ProductsUpdate](docs/ProductsUpdate.md)
 - [ProviderCode](docs/ProviderCode.md)
 - [RefundStatus](docs/RefundStatus.md)
 - [Refunds](docs/Refunds.md)
 - [RefundsCreate](docs/RefundsCreate.md)
 - [RefundsUpdate](docs/RefundsUpdate.md)
 - [SpiAccountAliases](docs/SpiAccountAliases.md)
 - [SpiAccountAliasesCreate](docs/SpiAccountAliasesCreate.md)
 - [SpiAccountAliasesUpdate](docs/SpiAccountAliasesUpdate.md)
 - [SpiAccountStatus](docs/SpiAccountStatus.md)
 - [SpiAccountType](docs/SpiAccountType.md)
 - [SpiPaymentStatus](docs/SpiPaymentStatus.md)
 - [SpiQrCodes](docs/SpiQrCodes.md)
 - [SpiQrCodesCreate](docs/SpiQrCodesCreate.md)
 - [SpiQrCodesUpdate](docs/SpiQrCodesUpdate.md)
 - [SubscriptionStatus](docs/SubscriptionStatus.md)
 - [Subscriptions](docs/Subscriptions.md)
 - [SubscriptionsCreate](docs/SubscriptionsCreate.md)
 - [SubscriptionsUpdate](docs/SubscriptionsUpdate.md)
 - [TransactionStatus](docs/TransactionStatus.md)
 - [Transactions](docs/Transactions.md)
 - [TransactionsCreate](docs/TransactionsCreate.md)
 - [TransactionsUpdate](docs/TransactionsUpdate.md)
 - [WebhookDeliveryLogs](docs/WebhookDeliveryLogs.md)
 - [WebhookDeliveryLogsCreate](docs/WebhookDeliveryLogsCreate.md)
 - [WebhookDeliveryLogsUpdate](docs/WebhookDeliveryLogsUpdate.md)
 - [WebhookEvent](docs/WebhookEvent.md)
 - [Webhooks](docs/Webhooks.md)
 - [WebhooksCreate](docs/WebhooksCreate.md)
 - [WebhooksUpdate](docs/WebhooksUpdate.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

hello@lomi.africa


